; generate_data_file_path takes a base data directory, the date in an
; Acetime struct, and a suffix to append to the end of the data file.
; It uses the part of the L1_[CRIS|SIS]_DATA_BASE_DIRECTORY environment
; variable after "data" to create a prefix for the file name for easy
; identification of the file any time later.
;
; use:
;	print, getenv('L1_SIS_DATA_BASE_DIRECTORY')
;    /home/idunn1/rgr/prototype/data/sis/
;
;	baseDir = getenv('L1_SIS_DATA_BASE_DIRECTORY')
;
;	day1996 = 457
;	time = get_date_from_day_1996(day1996)
;	suffix = 'evt'
;	path = generate_data_file_path(baseDir, time, suffix)
;	print, path
;    /home/idunn1/rgr/prototype/data/sis/1997.04/1997.04.01/sis.1997.04.01.evt
;	(hey, that's april fools!  best beware... :)

function generate_data_file_path, baseDir, time, suffix
    ; reminder of what time is: time = {AceTime}

    dirParts = str_sep(baseDir, '/')
    lastIndex = n_elements(dirParts) - 1
    for i = 0, lastIndex do begin
	if (dirParts[i] EQ 'data') then goto, OUT
    endfor
    print, baseDir, ' does not include a data directory.  Stopping.'
    stop
OUT:
    namePrefix = ''
    for j = i + 1, lastIndex do begin
	namePrefix = namePrefix + dirParts[j] + '.'
    endfor

    yearString = strtrim(string(time.year), 2)

    monthString = strtrim(string(time.month), 2)
    if (strlen(monthString) EQ 1) then monthString = '0' + monthString

    yearMonthString = yearString + '.' + monthString

    mdayString = strtrim(string(time.day), 2)
    if (strlen(mdayString) EQ 1) then mdayString = '0' + mdayString

    dateString = yearMonthString + '.' + mdayString

    dir = baseDir
    if (strpos(dir, '/', strlen(dir) - 1) EQ -1) then dir = dir + '/'
    dir = dir + yearMonthString + '/' + dateString 

    filePath = dir + '/' + namePrefix + dateString + '.' + suffix
    return, filePath
end
