function get_begin_end_secs_of_struct_prior_to, secondsSince1996,	    $
						dataFilePath, structToUse
    HEADER_LENGTH = 32
    beginAndEndTimeTags = lonarr(2)

    structName = strlowcase(tag_names(structToUse, /STRUCTURE_NAME))
    ct = 0	; command tables
    de = 0	; diagnostic events
    if (strpos(structName, 'commandtable') GE 0) then ct = 1		    $
    else if (strpos(structName, 'diagnosticevent') GE 0) then de = 1	    $
    else begin
	    ; no other structures should be using this routine
	print, 'Error: calling the get_begin_end_secs_of_struct_prior_to'
	print, 'for the ', structName, ' structure is not valid.'
	print, 'Stopping.'
	stop
    endelse

    day = get_day_1996_from_seconds_since_1996(secondsSince1996)
    aceTimeStruct = get_date_from_day_1996(day)
    dayStartSecond = cvttosec1996(aceTimeStruct)
    secondsSince12AM = secondsSince1996 - dayStartSecond

    if (file_exists(dataFilePath) LT 1) then begin
	    ; file does not exist
	; print, 'WARNING: File ', dataFilePath, ' does not exist.'
	; print, 'No data that day?  Checking previous days events.'
	index = -1
	goto, OUT5
    endif

    structCount = get_files_struct_count(dataFilePath, structToUse)
    index = fix(structCount * (secondsSince12AM / 86400.))	; init guess

    get_lun, lun
    openr, lun, dataFilePath

    fileAssoc = assoc(lun, structToUse, HEADER_LENGTH)

    struct = fileAssoc[index]
    if (ct OR de) then stamp = struct.Second1996MinorFrame0
    ; print, '1: ', stamp, index
	; step forward past zero structs
    while (stamp EQ 0) do begin
	index = index + 1
	if (index EQ structCount) then goto, OUT1
	struct = fileAssoc[index]
	if (ct OR de) then stamp = struct.Second1996MinorFrame0
        ; print, '2: ', stamp, index
    endwhile

    OUT1:
    if ((stamp NE 0) AND (stamp LE secondsSince1996)) then begin
	    ; step forward past structs occuring before secondsSince1996
	while (stamp LE secondsSince1996) do begin
	    index = index + 1
	    if (index EQ structCount) then goto, OUT2
	    struct = fileAssoc[index]
	    if (ct OR de) then stamp = struct.Second1996MinorFrame0
            ; print, '3: ', stamp, index
	endwhile

	OUT2:
	    ; step back one struct
	index = index - 1
	struct = fileAssoc[index]
	if (ct OR de) then stamp = struct.Second1996MinorFrame0
	; print, '4: ', stamp, index
	    ; also step back past any zero structs
	while (stamp EQ 0) do begin
	    index = index - 1
	    if (index LT 0) then goto, OUT3
	    struct = fileAssoc[index]
	    if (ct OR de) then stamp = struct.Second1996MinorFrame0
	    ; print, '5: ', stamp, index
	endwhile

	OUT3:
    endif								    $
    else begin
	    ; step back before structs occuring later than secondsSince1996
	    ; also ignore zero time stamps
	while ((stamp GT secondsSince1996) OR (stamp EQ 0)) do begin
	    index = index - 1
	    if (index LT 0) then goto, OUT4
	    struct = fileAssoc[index]
	    if (ct OR de) then stamp = struct.Second1996MinorFrame0
	    ; print, '6: ', stamp, index
	endwhile

	OUT4:
    endelse

    OUT5:

    if (index GE 0) then begin
	    ; prior non-zero struct lies in this day's structs (thank god)
	if (ct OR de) then begin
	    struct = fileAssoc[index]
	    beginAndEndTimeTags[0] = struct.Second1996MinorFrame0
	    beginAndEndTimeTags[1] = struct.Second1996MinorFrame1
	endif
	close, lun
	free_lun, lun
	return, beginAndEndTimeTags
    endif								    $
    else begin
	    ; ugh! deal with looking in the previous day's data file...

	    ; determine path to previous day's data file
	day = day - 1
	timeStruct = get_date_from_day_1996(day)
	pathParts = str_sep(dataFilePath, '/')
	lastIndex = n_elements(pathParts) - 1
	basePath = ''
	for i = 0, lastIndex - 3 do begin	; remove 1997.09/1997.09.24/file
	    basePath = basePath + pathParts[i]
	    if (i NE (lastIndex - 3)) then basePath = basePath + '/'
	endfor
	originalFileName = pathParts[lastIndex]
	nameParts = str_sep(originalFileName, '.')
	suffix = nameParts[n_elements(nameParts) - 1]
	previousDaysPath = generate_data_file_path(basePath, timeStruct, suffix)

	if (file_exists(previousDaysPath) LT 1) then begin
		; file does not exist.  return null times
	    ; print, 'WARNING: File ', previousDaysPath, ' does not exist.'
	    ; print, 'No data that day?'
	    beginAndEndTimeTags[0] = 0
	    beginAndEndTimeTags[1] = 0
	    close, lun
	    free_lun, lun
	    return, beginAndEndTimeTags
	endif

	    ; look for last non-zero struct in previous day's file
	structCount = get_files_struct_count(previousDaysPath, structToUse)
	get_lun, lun
	openr, lun, previousDaysPath
	fileAssoc = assoc(lun, structToUse, HEADER_LENGTH)
	index = structCount - 1
	struct = fileAssoc[index]
	if (ct OR de) then stamp = struct.Second1996MinorFrame0
	; print, '7: ', stamp, index
	    ; step back past zero structs
	while (stamp EQ 0) do begin
	    index = index - 1
	    if (index LT 0) then goto, OUT6
	    struct = fileAssoc[index]
	    if (ct OR de) then stamp = struct.Second1996MinorFrame0
	    ; print, '8: ', stamp, index
	endwhile

	OUT6:
	if (index GE 0) then begin
		; found a non-zero struct
	    if (ct OR de) then begin
		struct = fileAssoc[index]
		beginAndEndTimeTags[0] = struct.Second1996MinorFrame0
		beginAndEndTimeTags[1] = struct.Second1996MinorFrame1
	    endif
	    close, lun
	    free_lun, lun
	    return, beginAndEndTimeTags
	endif								    $
	else begin
		; did not find a non-zero struct
	    beginAndEndTimeTags[0] = 0
	    beginAndEndTimeTags[1] = 0
	    close, lun
	    free_lun, lun
	    return, beginAndEndTimeTags
	endelse

	close, lun
	free_lun, lun
    endelse
end
